import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'
import { getDept } from "@/api/system/dept";

const user = {
  state: {
    token: getToken(),
    name: '',
    nickName:'',
    deptId:'',
    avatar: '',
    roles: [],
    permissions: [],
    jiBie:'',
    deptName:'',
    agentFlag:false,
    userId:'',
    levelId:''
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_NICKNAME: (state, nickName) => {
      state.nickName = nickName
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_DEPT:(state, deptId)=>{
      state.deptId=deptId
    },
    SET_JIBIE:(state, jiBie)=>{
      state.jiBie = jiBie
    },
    SET_DEPTNAME:(state, deptName)=>{
      state.deptName = deptName
    },
    SET_AGENTFLAG:(state, agentFlag)=>{
      state.agentFlag = state.jiBie != 0 ? false : agentFlag === "1" ? true : false;
    },
    SET_USERID:(state, userId)=>{
      state.userId = userId
    },
    SET_LEVELID:(state, levelId)=>{
      state.levelId = levelId
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo(state.token).then(res => {
          const user = res.user
          const avatar = user.avatar == "" ? require("@/assets/image/profile.jpg") : process.env.VUE_APP_BASE_API + user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_NAME', user.userName)
          commit('SET_NICKNAME', user.nickName)
          commit('SET_AVATAR', avatar)
          commit('SET_DEPT', user.deptId)
          
          commit("SET_USERID",user.userId)
          commit("SET_JIBIE",user.dept.jiBie)
          commit("SET_DEPTNAME",user.dept.deptName)
          commit("SET_AGENTFLAG",user.agentFlag)

          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },
    
    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          commit('SET_DEPT', '')
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
